/*****************************************************
* C specific Serial I/O support for stdio.h *
*                                                    *
* Will require editing for other chips with          *
* different USART modules.                           *
******************************************************/
#ifndef __AVR_ATmega328P__
#error Must build for AVR ATmega328P
#endif

#include <avr/io.h>
#include <stdio.h>
#include "AVR_UART_IO.h"

void UART_Init( unsigned int ubrr)
{
/*Set baud rate */
UBRR0H = (unsigned char)(ubrr>>8);
UBRR0L = (unsigned char)ubrr;
/* Enable receiver and transmitter */
UCSR0B = (1<<RXEN0)|(1<<TXEN0);
/* Set frame format: 8data, 2stop bit */
UCSR0C = (1<<USBS0)|(3<<UCSZ00);
}

static int uart_putchar(char c, FILE *stream){
   if (c == '\n')
      uart_putchar('\r', stream);
   /* Wait for empty transmit buffer */
   do {} while ( !( UCSR0A & (1<<UDRE0)) );
   /* Put data into buffer, sends the data */
   UDR0 = c;
   return 0;
}
static int uart_getchar( FILE *stream){
   /* Wait for data to be received */
   do {} while ( !(UCSR0A & (1<<RXC0)) );
   /* Get and return received data from buffer */
   return UDR0;
}

/* Set up stream */ 
FILE UARTstdio = FDEV_SETUP_STREAM(uart_putchar, uart_getchar, _FDEV_SETUP_RW); 
/************************************/


